/* -*- c++ -*- */
/*
 * Copyright 2006,2009,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#if HAVE_CONFIG_H
#include <config.h>
#endif

#include <gnuradio/constants.h>
#include <boost/dll/runtime_symbol_info.hpp>
#include <cstdlib>
#include <filesystem>

using std::filesystem::path;

namespace gr {
const std::string prefix()
{
    // Use "GR_PREFIX" environment variable when specified
    const char* prefix = std::getenv("GR_PREFIX");
    if (prefix != NULL)
        return prefix;

    path prefix_rel_lib = "../";
    path gr_runtime_lib_path = boost::dll::this_line_location().string();
    // Canonize before decomposing path so result is reliable and without symlinks
    path canonical_lib_path = std::filesystem::canonical(gr_runtime_lib_path);
    path prefix_path = canonical_lib_path.parent_path() / prefix_rel_lib;
    return prefix_path.lexically_normal().string();
}

const std::string sysconfdir()
{
    path sysconfdir_rel_prefix = "../etc";
    path prefix_path = prefix();
    path sysconfdir_path = prefix_path / sysconfdir_rel_prefix;

    return sysconfdir_path.lexically_normal().string();
}

const std::string prefsdir()
{
    path prefsdir_rel_prefix = "../etc/gnuradio/conf.d";
    path prefix_path = prefix();
    path prefsdir_path = prefix_path / prefsdir_rel_prefix;

    return prefsdir_path.lexically_normal().string();
}

const std::string build_date() { return "Sat, 10 May 2025 21:20:21Z"; }

const std::string version() { return "3.10.11.0"; }

// Return individual parts of the version
const std::string major_version() { return "3"; }

const std::string api_version() { return "10"; }

const std::string minor_version() { return "11"; }

const std::string c_compiler() { return "x86_64-pld-linux-gcc (PLD-Linux) 14.2.0 20250315 (release) \nCopyright (C) 2024 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string cxx_compiler() { return "x86_64-pld-linux-g++ (PLD-Linux) 14.2.0 20250315 (release) \nCopyright (C) 2024 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string compiler_flags() { return "/usr/bin/x86_64-pld-linux-gcc::: -O2 -fwrapv -pipe -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Werror=trampolines -fPIC -march=x86-64 -mtune=generic -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wformat -Werror=format-security  -DNDEBUG -DQT_NO_DEBUG -fvisibility=hidden -Wsign-compare -Wall -Wno-uninitialized -Wignored-qualifiers -Wcast-qual \n/usr/bin/x86_64-pld-linux-g++::: -O2 -fwrapv -pipe -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Werror=trampolines -fPIC -march=x86-64 -mtune=generic -gdwarf-4 -fno-debug-types-section -fvar-tracking-assignments -g2 -Wformat -Werror=format-security  -DNDEBUG -DQT_NO_DEBUG -fvisibility=hidden -Wsign-compare -Wall -Wno-uninitialized -Wignored-qualifiers -Wcast-qual"; }

const std::string build_time_enabled_components() { return "testing-support;python-support;post-install;doxygen;man-pages;gnuradio-runtime;common-precompiled-headers;gr-ctrlport;gnuradio-companion;JSON/YAML config blocks;gr-blocks;gr-fec;gr-fft;gr-filter;gr-analog;gr-digital;gr-dtv;gr-audio;* alsa;* oss;* jack;* portaudio;gr-channels;gr-pdu;gr-qtgui;gr-trellis;gr-uhd;gr-uhd UHD 4.0 RFNoC;gr-utils;gr_modtool;gr_blocktool;gr-video-sdl;gr-vocoder;* codec2;* freedv;* gsm;gr-wavelet;gr-zeromq;gr-network"; }

const std::string pybind_version() { return "2.13.6"; }

} /* namespace gr */
